Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: chrome/common/extensions/feature.h

Issue 9460002: Convert app_bindings.js to the schema_generated_bindings.js infrastructure. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix koz bool thing Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/feature.h
diff --git a/chrome/common/extensions/feature.h b/chrome/common/extensions/feature.h
index 0a956890be5918ddad00c873c5540ea9f8409dc2..90cd920faa7c868102a3a36743775acb2d03ca05 100644
--- a/chrome/common/extensions/feature.h
+++ b/chrome/common/extensions/feature.h
@@ -24,9 +24,18 @@ class Feature {
// The JavaScript contexts the feature is supported in.
enum Context {
UNSPECIFIED_CONTEXT,
- PRIVILEGED_CONTEXT, // A context in a privileged extension process.
- UNPRIVILEGED_CONTEXT, // A context in a normal, unprivileged renderer.
- CONTENT_SCRIPT_CONTEXT // A context from a content script.
+
+ // A context in a privileged extension process.
+ PRIVILEGED_CONTEXT,
+
+ // A context in a normal, unprivileged renderer.
+ UNPRIVILEGED_CONTEXT,
+
+ // A context from a content script.
+ CONTENT_SCRIPT_CONTEXT,
+
+ // A normal web page. This should have an associated URL matching pattern.
+ WEB_PAGE_CONTEXT,
};
// The location required of extensions the feature is supported in.

Powered by Google App Engine
This is Rietveld 408576698